@@ -25,6 +25,8 @@ all_commands = (
     "hook",
     "info",
     "install",
+    "list",
+    "register",
     "verify",
     )
 
